@@ -628,7 +628,6 @@ static void
 load_dir (GtkFileFolderGnomeVFS *folder_vfs)
 {
   int num_items;
-  GnomeVFSFileInfoOptions vfs_options;
 
   profile_start ("start", folder_vfs->uri);
 
@@ -645,11 +644,6 @@ load_dir (GtkFileFolderGnomeVFS *folder_vfs)
   else
     num_items = ITEMS_PER_REMOTE_NOTIFICATION;
 
-  if (folder_vfs->is_afs_or_net)
-    vfs_options = GNOME_VFS_FILE_INFO_DEFAULT;
-  else
-    vfs_options = get_options (folder_vfs->types);
-
   gnome_vfs_async_load_directory (&folder_vfs->async_handle,
 				  folder_vfs->uri,
 				  get_options (folder_vfs->types),
